Method: Google::Base#sync_attributes
- Defined in:
- lib/google/base.rb
#sync_attributes ⇒ Object
specify how attributes are mapped to the spreadsheet.
Example
{
:timestamp => Time.now.to_s(:db),
:message => @message
}
The keys in the hash represent columns in the spreadsheet (check out the Readme, for more information about attribute mapping), the values will be written to the cells.
74 75 76 |
# File 'lib/google/base.rb', line 74 def sync_attributes { } end |